# Getting started

## Installation
This package is hosted on [PyPl](https://pypi.org/project/guibbon), you can install the **latest stable release** with pip:
```
pip install guibbon
```
If stability is not for you, install the rolling version from github. You will get early access to new **features**, **bugfixes** and **bugs**:
```
pip install git+https://github.com/ManuGira/Guibbon.git@master
```

